@@ -27,6 +27,7 @@ class CampaignInfo(ResolvableCompanyModel):
     campaign_goal: Optional[CampaignGoal]
     feed: FeedInfo
     selection_criteria: Optional[dict]
+    application_flow_settings: Optional[dict]
 
     @staticmethod
     async def resolve_object(object_id: UUID, organization_id: UUID) -> "CampaignInfo | None":
@@ -56,7 +57,8 @@ class CampaignInfo(ResolvableCompanyModel):
             channel_type=model.channel_type,
             campaign_goal=model.campaign_goal,
             feed=feed,
-            selection_criteria=model.selection_criteria
+            selection_criteria=model.selection_criteria,
+            application_flow_settings=model.application_flow_settings
         )
 
 
@@ -76,6 +78,7 @@ class CampaignConfig(BaseModel):
     campaign_goal: Optional[CampaignGoal]
     feed_id: UUID
     selection_criteria: Optional[dict]
+    application_flow_settings: Optional[dict]
 
     @classmethod
     async def from_model(cls: "CampaignConfig", model: CampaignModel) -> 'CampaignConfig':
