@@ -28,8 +28,10 @@ class AdStatus(enum.Enum):
     DRAFT = 'draft'
     LIVE = 'live'
     PUBLISHING = 'publishing'
+    PUBLISHING_ERROR = 'publishing-error'
     PAUSING = 'pausing'
     PAUSED = 'paused'
+    PAUSING_ERROR = 'pausing-error'
     ARCHIVED = 'archived'
     DELETED = 'deleted'
 
@@ -38,8 +40,10 @@ class CampaignStatus(enum.Enum):
     DRAFT = 'draft'
     LIVE = 'live'
     PUBLISHING = 'publishing'
+    PUBLISHING_ERROR = 'publishing-error'
     PAUSING = 'pausing'
     PAUSED = 'paused'
+    PAUSING_ERROR = 'pausing-error'
     ARCHIVED = 'archived'
     DELETED = 'deleted'
 
@@ -65,14 +69,14 @@ class Campaign(CampaignsOrganizationModel, table=True):
     selection_criteria: dict = Field(sa_column=Column(JSON))
     application_flow_settings: dict = Field(sa_column=Column(JSON))
 
-    ad_sets: list["AdSet"] = Relationship(back_populates="campaign")
-    ads: list["Ad"] = Relationship(back_populates="campaign")
+    ad_sets: list["AdSet"] = Relationship(back_populates="campaign", cascade_delete=True)
+    ads: list["Ad"] = Relationship(back_populates="campaign", cascade_delete=True)
 
 
 class AdSet(CampaignsOrganizationModel, table=True):
     name: str = Field(index=True)
     external_id: Optional[str] = Field(index=True)
-    status: AdStatus = Field(sa_column=Column(Enum(AdStatus)), default=CampaignStatus.DRAFT)
+    status: AdStatus = Field(sa_column=Column(Enum(AdStatus)), default=AdStatus.DRAFT)
     platforms: list = Field(sa_column=Column(JSON))
     ad_types: list = Field(sa_column=Column(JSON))
     settings: dict = Field(sa_column=Column(JSON))
@@ -100,7 +104,7 @@ class TargetAudience(CampaignsOrganizationModel, table=True):
 class Ad(CampaignsOrganizationModel, table=True):
     name: str = Field(index=True)
     external_id: Optional[str] = Field(index=True)
-    status: AdStatus = Field(sa_column=Column(Enum(AdStatus)), default=CampaignStatus.DRAFT)
+    status: AdStatus = Field(sa_column=Column(Enum(AdStatus)), default=AdStatus.DRAFT)
     vacancy_id: Optional[UUID] = Field()
     lead_form: Optional[UUID] = Field(foreign_key="leadform.id")
     primary_text: str = Field()
