@@ -55,7 +55,7 @@ class Feed(VacanciesOrganizationModel, table=True):
     last_sync_date: Optional[datetime] = Field()
     source_type: SourceType =  Field(sa_column=Column(Enum(SourceType)))
     synced_vacancy_count: int = Field(default=0)
-    sanitize_options: Optional[dict] = Field(sa_column=Column(JSON), default=None)
+    sanitation_options: Optional[dict] = Field(sa_column=Column(JSON), default=None)
     mapping: list = Field(sa_column=Column(JSON))
     custom_fields: list = Field(sa_column=Column(JSON))
 
